| Title: | Permutation Based Paired Kolmogorov-Smirnov Test |
|---|---|
| Description: | Permutation based Kolmogorov-Smirnov test for paired samples. The test was proposed by Wang W.S., Amsler C. and Schmidt, P. (2025) <doi:10.1007/s00181-025-02779-0>. |
| Authors: | Michail Tsagris [aut, cre] |
| Maintainer: | Michail Tsagris <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-25 08:17:49 UTC |
| Source: | https://github.com/cran/ppks |
Permutation Based Paired Kolmogorov-Smirnov Test
| Package: | ppks |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2025-09-21 |
| License: | GPL-2 |
Michail Tsagris <[email protected]>
Michail Tsagris [email protected].
Wang W.S., Amsler C. and Schmidt, P. (2025). A randomly swapped bootstrap for paired data: testing equality of distribution for correlated samples. Empirical Economics, To appear. https://link.springer.com/article/10.1007/s00181-025-02779-0
Permutation Based Paired Kolmogorov-Smirnov Test
colppks(x, y, R = 999)colppks(x, y, R = 999)
x |
A numerical matrix with data. |
y |
A numerical matrix with data. |
R |
The number of permutations to perform. |
The permutation based Kolmogorov-Smirnov test for paired samples (Wang W.S., Amsler C. and Schmidt, P., 2025) is performed. The x and y matrices contain the paired observations. The i-th column of x is paired with the i-th column of y.
A vector with permutation based p-values. Each p-value corresponds to a column in the matrices.
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Wang W.S., Amsler C. and Schmidt, P. (2025). A randomly swapped bootstrap for paired data: testing equality of distribution for correlated samples. Empirical Economics, To appear. https://link.springer.com/article/10.1007/s00181-025-02779-0
x <- matrix( rnorm(30 * 10), ncol = 10 ) y <- x + rnorm(30 * 10) colppks(x, y)x <- matrix( rnorm(30 * 10), ncol = 10 ) y <- x + rnorm(30 * 10) colppks(x, y)
Permutation Based Paired Kolmogorov-Smirnov Test
ppks(x, y, R = 999)ppks(x, y, R = 999)
x |
A numerical vector with data. |
y |
A numerical vector with data. |
R |
The number of permutations to perform. |
The permutation based Kolmogorov-Smirnov test for paired samples (Wang W.S., Amsler C. and Schmidt, P., 2025) is performed. The x and y vectors contain the paired observations.
The permutation based p-value.
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Wang W.S., Amsler C. and Schmidt, P. (2025). A randomly swapped bootstrap for paired data: testing equality of distribution for correlated samples. Empirical Economics, To appear. https://link.springer.com/article/10.1007/s00181-025-02779-0
x <- rnorm(30) y <- x + rnorm(30) ppks(x, y)x <- rnorm(30) y <- x + rnorm(30) ppks(x, y)